.. include:: ../README.rst

API
---

.. toctree::
   :maxdepth: 2

   scene
   mapper
   formatter
   renderer
   sky

   sampler
   lightpoint
   evaluate
   craytraverse

   io
   plot
   translate

.. include:: ../ACKNOWLEDGEMENTS.rst

.. toctree::
   :maxdepth: 3
   :hidden:

   history
   genindex
   search
   todo
   git
